@@ -27,14 +27,14 @@ class PortableMediaPlayer : public DeviceInterface, virtual public Solid::Ifaces
 
 public:
     PortableMediaPlayer(UDevDevice *device);
-    virtual ~PortableMediaPlayer();
+    ~PortableMediaPlayer() override;
 
     QStringList supportedProtocols() const override;
     QStringList supportedDrivers(QString protocol = QString()) const override;
     QVariant driverHandle(const QString &driver) const override;
 
 private:
-    /**
+    /*!
      * Return full absolute path to media-player-info .mpi file, based on ID_MEDIA_PLAYER
      * udev property. Does not check for existence. Returns empty string in case no reasonable
      * file path could be determined.
