@@ -37,9 +37,9 @@ int Processor::number() const
 int Processor::maxSpeed() const
 {
     if (m_maxSpeed == -1) {
-        QFile cpuMaxFreqFile(m_device->deviceName() + prefix() + "/cpufreq/cpuinfo_max_freq");
+        QFile cpuMaxFreqFile(m_device->deviceName() + prefix() + QStringLiteral("/cpufreq/cpuinfo_max_freq"));
         if (cpuMaxFreqFile.open(QIODevice::ReadOnly)) {
-            QString value = cpuMaxFreqFile.readAll().trimmed();
+            QByteArray value = cpuMaxFreqFile.readAll().trimmed();
             // cpuinfo_max_freq is in kHz
             m_maxSpeed = static_cast<int>(value.toLongLong() / 1000);
         }
@@ -59,8 +59,8 @@ bool Processor::canChangeFrequency() const
 
         m_canChangeFrequency = CannotChangeFreq;
 
-        QFile cpuMinFreqFile(m_device->deviceName() + prefix() + "/cpufreq/cpuinfo_min_freq");
-        QFile cpuMaxFreqFile(m_device->deviceName() + prefix() + "/cpufreq/cpuinfo_max_freq");
+        QFile cpuMinFreqFile(m_device->deviceName() + prefix() + QStringLiteral("/cpufreq/cpuinfo_min_freq"));
+        QFile cpuMaxFreqFile(m_device->deviceName() + prefix() + QStringLiteral("/cpufreq/cpuinfo_max_freq"));
         if (cpuMinFreqFile.open(QIODevice::ReadOnly) && cpuMaxFreqFile.open(QIODevice::ReadOnly)) {
             qlonglong minFreq = cpuMinFreqFile.readAll().trimmed().toLongLong();
             qlonglong maxFreq = cpuMaxFreqFile.readAll().trimmed().toLongLong();
